<!-- markdownlint-disable MD033 MD036 MD041 -->

<div align="center">

_Logo 征集中_

# Cookit

_✨ 自用工具集 ✨_

<img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">
<a href="https://pdm.fming.dev">
  <img src="https://img.shields.io/badge/pdm-managed-blueviolet" alt="pdm-managed">
</a>
<a href="https://wakatime.com/badge/user/b61b0f9a-f40b-4c82-bc51-0a75c67bfccf/project/018e2a1e-94fe-4cd2-941c-8a606b671263">
  <img src="https://wakatime.com/badge/user/b61b0f9a-f40b-4c82-bc51-0a75c67bfccf/project/018e2a1e-94fe-4cd2-941c-8a606b671263.svg" alt="wakatime">
</a>

<br />

<a href="https://pydantic.dev">
  <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/lgc-NB2Dev/readme/main/template/pyd-v1-or-v2.json" alt="Pydantic Version 1 Or 2" >
</a>
<a href="./LICENSE">
  <img src="https://img.shields.io/github/license/lgc2333/cookit.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/cookit">
  <img src="https://img.shields.io/pypi/v/cookit.svg" alt="pypi">
</a>
<a href="https://pypi.python.org/pypi/cookit">
  <img src="https://img.shields.io/pypi/dm/cookit" alt="pypi download">
</a>

</div>

## 📖 介绍

暂无

## 💿 安装

_可选依赖请自行查看 `pyproject.toml`_

```bash
pip install cookit[all]
```

## 📞 联系

QQ：3076823485  
Telegram：[@lgc2333](https://t.me/lgc2333)  
吹水群：[1105946125](https://jq.qq.com/?_wv=1027&k=Z3n1MpEp)  
邮箱：<lgc2333@126.com>

<!-- ## 💡 鸣谢 -->

## 💰 赞助

**[赞助我](https://blog.lgc2333.top/donate)**

感谢大家的赞助！你们的赞助将是我继续创作的动力！

## 📝 更新日志

暂无
